@@ -10,7 +10,6 @@ from typing import Dict, List, Tuple
 from sacrerouge.commands import MetricSetupSubcommand
 from sacrerouge.common import DATA_ROOT, TemporaryDirectory
 from sacrerouge.data import MetricsDict
-from sacrerouge.data.jackknifers import ReferencesJackknifer
 from sacrerouge.data.types import ReferenceType, SummaryType
 from sacrerouge.metrics import Metric, ReferenceBasedMetric
 
@@ -23,7 +22,7 @@ class PyrEval(ReferenceBasedMetric):
                  environment_name: str = None,
                  pyreval_root: str = f'{DATA_ROOT}/metrics/PyrEval',
                  verbose: bool = False):
-        super().__init__(['summary'], ['references'], jackknifer=ReferencesJackknifer())
+        super().__init__()
         self.environment_name = environment_name
         self.pyreval_root = pyreval_root
         self.verbose = verbose
@@ -91,6 +90,13 @@ class PyrEval(ReferenceBasedMetric):
         if os.path.exists(results_file):
             os.remove(results_file)
 
+    def _assert_has_multiple_references(self, references_list: List[List[ReferenceType]]) -> None:
+        # PyrEval cannot handle summaries with single references. See https://github.com/serenayj/PyrEval/issues/11
+        for references in references_list:
+            if len(references) == 1:
+                raise Exception(f'PyrEval cannot be run with one reference summary. '
+                                f'See https://github.com/serenayj/PyrEval/issues/11 for more details')
+
     def _flatten_summaries(self, summaries_list: List[List[SummaryType]]) -> List[List[str]]:
         flat_list = []
         for summaries in summaries_list:
@@ -291,6 +297,8 @@ class PyrEval(ReferenceBasedMetric):
     def score_multi_all(self,
                         summaries_list: List[List[SummaryType]],
                         references_list: List[List[ReferenceType]]) -> List[List[MetricsDict]]:
+        self._assert_has_multiple_references(references_list)
+
         # The original code for PyrEval processes exactly 1 pyramid at a time. Therefore, the whole pipeline needs
         # to be run once per item in `references_list`. Each execution of the pipeline will load the Stanford CoreNLP
         # models and run them over the text. Loading the models takes a lot of time, and the preprocessing of
